==> pipewire-docs-1%3A0.3.66-2-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/examples.js <==
var examples =
[
    [ "tutorial1.c", "tutorial1_8c-example.html", null ],
    [ "tutorial2.c", "tutorial2_8c-example.html", null ],
    [ "tutorial3.c", "tutorial3_8c-example.html", null ],
    [ "tutorial4.c", "tutorial4_8c-example.html", null ],
    [ "tutorial5.c", "tutorial5_8c-example.html", null ],
    [ "tutorial6.c", "tutorial6_8c-example.html", null ],
    [ "audio-src.c", "audio-src_8c-example.html", null ],
    [ "audio-dsp-src.c", "audio-dsp-src_8c-example.html", null ],
    [ "audio-dsp-filter.c", "audio-dsp-filter_8c-example.html", null ],
    [ "audio-capture.c", "audio-capture_8c-example.html", null ],
    [ "video-play.c", "video-play_8c-example.html", null ],
    [ "video-src.c", "video-src_8c-example.html", null ],
    [ "video-dsp-play.c", "video-dsp-play_8c-example.html", null ],
    [ "video-play-pull.c", "video-play-pull_8c-example.html", null ],
    [ "video-play-reneg.c", "video-play-reneg_8c-example.html", null ],
    [ "video-src-alloc.c", "video-src-alloc_8c-example.html", null ],
    [ "video-src-reneg.c", "video-src-reneg_8c-example.html", null ],
    [ "video-src-fixate.c", "video-src-fixate_8c-example.html", null ],
    [ "video-play-fixate.c", "video-play-fixate_8c-example.html", null ],
    [ "export-sink.c", "export-sink_8c-example.html", null ],
    [ "export-source.c", "export-source_8c-example.html", null ],
    [ "export-spa.c", "export-spa_8c-example.html", null ],
    [ "export-spa-device.c", "export-spa-device_8c-example.html", null ],
    [ "bluez-session.c", "bluez-session_8c-example.html", null ],
    [ "local-v4l2.c", "local-v4l2_8c-example.html", null ],
    [ "spa/examples/adapter-control.c", "spa_2examples_2adapter-control_8c-example.html", null ],
    [ "spa/examples/example-control.c", "spa_2examples_2example-control_8c-example.html", null ],
    [ "spa/examples/local-libcamera.c", "spa_2examples_2local-libcamera_8c-example.html", null ],
    [ "spa/examples/local-v4l2.c", "spa_2examples_2local-v4l2_8c-example.html", null ]
];

==> pipewire-docs-1%3A1.2.7-1-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/examples.js <==
var examples =
[
    [ "tutorial1.c", "tutorial1_8c-example.html", null ],
    [ "tutorial2.c", "tutorial2_8c-example.html", null ],
    [ "tutorial3.c", "tutorial3_8c-example.html", null ],
    [ "tutorial4.c", "tutorial4_8c-example.html", null ],
    [ "tutorial5.c", "tutorial5_8c-example.html", null ],
    [ "tutorial6.c", "tutorial6_8c-example.html", null ],
    [ "audio-src.c", "audio-src_8c-example.html", null ],
    [ "audio-dsp-src.c", "audio-dsp-src_8c-example.html", null ],
    [ "audio-dsp-filter.c", "audio-dsp-filter_8c-example.html", null ],
    [ "audio-capture.c", "audio-capture_8c-example.html", null ],
    [ "video-play.c", "video-play_8c-example.html", null ],
    [ "video-src.c", "video-src_8c-example.html", null ],
    [ "video-dsp-play.c", "video-dsp-play_8c-example.html", null ],
    [ "video-dsp-src.c", "video-dsp-src_8c-example.html", null ],
    [ "video-play-pull.c", "video-play-pull_8c-example.html", null ],
    [ "video-play-reneg.c", "video-play-reneg_8c-example.html", null ],
    [ "video-src-alloc.c", "video-src-alloc_8c-example.html", null ],
    [ "video-src-reneg.c", "video-src-reneg_8c-example.html", null ],
    [ "video-src-fixate.c", "video-src-fixate_8c-example.html", null ],
    [ "video-play-fixate.c", "video-play-fixate_8c-example.html", null ],
    [ "midi-src.c", "midi-src_8c-example.html", null ],
    [ "internal.c", "internal_8c-example.html", null ],
    [ "export-sink.c", "export-sink_8c-example.html", null ],
    [ "export-source.c", "export-source_8c-example.html", null ],
    [ "export-spa.c", "export-spa_8c-example.html", null ],
    [ "export-spa-device.c", "export-spa-device_8c-example.html", null ],
    [ "bluez-session.c", "bluez-session_8c-example.html", null ],
    [ "local-v4l2.c", "local-v4l2_8c-example.html", null ],
    [ "spa/examples/adapter-control.c", "spa_2examples_2adapter-control_8c-example.html", null ],
    [ "spa/examples/example-control.c", "spa_2examples_2example-control_8c-example.html", null ],
    [ "spa/examples/local-libcamera.c", "spa_2examples_2local-libcamera_8c-example.html", null ],
    [ "spa/examples/local-v4l2.c", "spa_2examples_2local-v4l2_8c-example.html", null ]
];
